spoon.spooncore

Package spoon :: Module spooncore |
[hide private]
[frames] | no frames]

# Module spooncore

source code

Classes | [hide private]
`` | serialprop When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.
`` | lazyprop When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.
`` | SpoonData
`` | SerialMeta
`` | Serial
`` | Memoizer Used as a substitute for the file object when serializing Serial objects, so reference cycles are caught and handled.
`` | StringIOWrap Stupid wrapper around StringIO because it isn't a new style class.
`` | LazyDict

Functions | [hide private]
`` | encode_stringio(fd, item)
`` | decode_stringio(fd, tag)
`` | encode_lazydict(fd, item)
`` | decode_lazydict(fd, tag) Decoding a lazy dict will just result in returning the entire object as a string.
`` | encode_dict(fd, item)
`` | decode_dict(fd, tag)
`` | encode_pyobjz(fd, obj)
`` | decode_pyobjz(fd, tag)
`` | encode_pyobj(fd, obj, omittag=False)
`` | decode_pyobj(fd, tag)
`` | decode_pyobj_ref(fd, tag)

Variables | [hide private]
`` | DICT_TAG = `<ASN.1 Tag(APPLICATION, 1, size=None, container=True)>`
`` | PYOBJ_TAG = `<ASN.1 Tag(APPLICATION, 2, size=None, container=True)>`
`` | PYOBJ_REF_TAG = `<ASN.1 Tag(APPLICATION, 3, size=None, container=False)>`
`` | LAZY_DICT_TAG = `<ASN.1 Tag(APPLICATION, 4, size=None, container=True)>`
`` | STRING_BUFF_TAG = `<ASN.1 Tag(APPLICATION, 5, size=None, container=True)>`
`` | PYOBJZ_TAG = `<ASN.1 Tag(APPLICATION, 6, size=None, container=False)>`
`` | SPOONLINKMSG_TAG = `<ASN.1 Tag(APPLICATION, 7, size=None, container=True)>`
`` | SPOONNETMSG_TAG = `<ASN.1 Tag(APPLICATION, 8, size=None, container=True)>`

Function Details | [hide private]

### encode_stringio(fd, item) | source code
None Decorators: `@ber.encoder(StringIOWrap)`

### decode_stringio(fd, tag) | source code
None Decorators: `@ber.decoder(STRING_BUFF_TAG)`

### encode_lazydict(fd, item) | source code
None Decorators: `@ber.encoder(LazyDict)`

### decode_lazydict(fd, tag) | source code
Decoding a lazy dict will just result in returning the entire object as a string. Decorators: `@ber.decoder(LAZY_DICT_TAG)`

### encode_dict(fd, item) | source code
None Decorators: `@ber.encoder(dict)`

### decode_dict(fd, tag) | source code
None Decorators: `@ber.decoder(DICT_TAG)`

### encode_pyobjz(fd, obj) | source code
None Decorators: `@ber.zencoder(Serial)`

### decode_pyobjz(fd, tag) | source code
None Decorators: `@ber.decoder(PYOBJZ_TAG)`

### encode_pyobj(fd, obj, omittag=False) | source code
None Decorators: `@ber.encoder(Serial)`

### decode_pyobj(fd, tag) | source code
None Decorators: `@ber.decoder(PYOBJ_TAG)`

### decode_pyobj_ref(fd, tag) | source code
None Decorators: `@ber.decoder(PYOBJ_REF_TAG)`

Variables Details | [hide private]

    ### DICT_TAG None Value:
        <ASN.1 Tag(APPLICATION, 1, size=None, container=True)>

    ### PYOBJ_TAG None Value:
        <ASN.1 Tag(APPLICATION, 2, size=None, container=True)>

    ### PYOBJ_REF_TAG None Value:
        <ASN.1 Tag(APPLICATION, 3, size=None, container=False)>

    ### LAZY_DICT_TAG None Value:
        <ASN.1 Tag(APPLICATION, 4, size=None, container=True)>

    ### STRING_BUFF_TAG None Value:
        <ASN.1 Tag(APPLICATION, 5, size=None, container=True)>

    ### PYOBJZ_TAG None Value:
        <ASN.1 Tag(APPLICATION, 6, size=None, container=False)>

    ### SPOONLINKMSG_TAG None Value:
        <ASN.1 Tag(APPLICATION, 7, size=None, container=True)>

    ### SPOONNETMSG_TAG None Value:
        <ASN.1 Tag(APPLICATION, 8, size=None, container=True)>